# QUEL-QAL: QUEL Quantitative Analysis Library

## License

### Source Code
The source code in this repository is licensed under the [GNU Affero General Public License v3.0 (AGPL-3.0)](https://www.gnu.org/licenses/agpl-3.0.html). 

### Documentation
The contents of the `doc` folder in this repository are licensed under the [Creative Commons Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/). 

### Notes
- If you contribute to this repository, you agree that your contributions to the source code will be licensed under AGPL-3.0 and your contributions to the documentation will be licensed under CC BY 4.0.
- Please ensure compliance with both licenses when using or modifying the content of this repository.